@@ -5,15 +5,15 @@ colVars <- function(x, suma = NULL, std = FALSE) {
   if ( !is.null(suma) ) {
     m <- suma
   } else {
-    m <- colSums(x)
+    m <- colsums(x)
   }
 
   n <- nrow(x)
-  x2 <- colSums(x^2)
+  x2 <- colsums(x^2)
   s <- ( x2 - m^2/n ) / (n - 1)
 
   if ( std == TRUE )  s <- sqrt(s)
 
   s
 
-}
+}
\ No newline at end of file
