@@ -17,7 +17,7 @@ dista <- function(xnew, x, type = "euclidean") {
 
     for (i in 1:nu) {
       z <- y - xnew[i, ]
-      disa[i, ] <- sqrt( colSums( z^2 ) )
+      disa[i, ] <- sqrt( colsums( z^2 ) )
     }
 
   } else if (type == "manhattan") {
@@ -25,10 +25,10 @@ dista <- function(xnew, x, type = "euclidean") {
 
     for (i in 1:nu) {
       a <- y - xnew[i, ]
-      disa[i, ] <- colSums( abs(a) )
+      disa[i, ] <- colsums( abs(a) )
     }
   }
 
   disa
 
-}
+}
\ No newline at end of file
