@@ -8,7 +8,7 @@ ftests <- function(x, ina) {
   for ( i in 1:k ) {
      y <- x[ina ==i, ]
      s[i, ] <- colVars( y )
-     m[i, ] <- colMeans(y)
+     m[i, ] <- colmeans(y)
   }
   
   w <- ni / s
@@ -23,8 +23,4 @@ ftests <- function(x, ina) {
 
   cbind(stat, pval)
 
-} 
-   
-  
-
-
+} 
\ No newline at end of file
