@@ -1,14 +1,14 @@
 standardise <- function(x, center = TRUE, scale = TRUE) {
 
   if ( center == TRUE & scale == TRUE ) {
-    m <- colMeans(x)
-    s <- colVars(x, std = TRUE)
+    m <- as.vector(colmeans(x))
+    s <- as.vector(colVars(x, std = TRUE))
     y <- ( t(x) - m ) / s
 
   } else if ( center == TRUE & scale == FALSE )  {
 
-    m <- colMeans(x)
-    s <- colVars(x, std = TRUE)
+    m <- as.vector(colmeans(x))
+    s <- as.vector(colVars(x, std = TRUE))
     y <- ( t(x) - m )
 
   } else if ( center == FALSE & scale == TRUE )  {
@@ -19,5 +19,4 @@ standardise <- function(x, center = TRUE, scale = TRUE) {
 
   t(y)
 
-}
-
+}
\ No newline at end of file
